==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QPickingProxy.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Can be used to provide an alternate QGeometryView used only for picking</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qpickingproxy.html">Qt3DRender::QPickingProxy</a></code></p>
 */
public class QPickingProxy extends io.qt.qt3d.core.QBoundingVolume
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickingProxy.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qpickingproxy.html#QPickingProxy">Qt3DRender::QPickingProxy::<wbr>QPickingProxy(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QPickingProxy(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPickingProxy instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QPickingProxy(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QPickingProxy(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QPickingProxy instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QPickingProxy(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QPickingProxy() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.0-sources.jar: io/qt/qt3d/render/QPickingProxy.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Can be used to provide an alternate QGeometryView used only for picking</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qpickingproxy.html">Qt3DRender::QPickingProxy</a></code></p>
 */
public class QPickingProxy extends io.qt.qt3d.core.QBoundingVolume
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickingProxy.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qpickingproxy.html#QPickingProxy">Qt3DRender::QPickingProxy::<wbr/>QPickingProxy(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QPickingProxy(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPickingProxy instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QPickingProxy(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QPickingProxy(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QPickingProxy instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QPickingProxy(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QPickingProxy() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
